macro_rules! trace_impl {
($t:ty) => { ... };
}Expand description
Register a type as the global executor trace hook implementation.
See raw::trace::Trace.
macro_rules! trace_impl {
($t:ty) => { ... };
}Register a type as the global executor trace hook implementation.
See raw::trace::Trace.